@@ -6,7 +6,6 @@ package data
 import (
 	"fmt"
 	"io"
-	"os"
 	"sync"
 
 	"github.com/derailed/k9s/internal/client"
@@ -29,6 +28,8 @@ func NewConfig(ct *api.Context) *Config {
 
 // Validate ensures config is in norms.
 func (c *Config) Validate(conn client.Connection, ks KubeSettings) {
+	c.mx.Lock()
+	defer c.mx.Unlock()
 
 	if c.Context == nil {
 		c.Context = NewContext()
@@ -42,19 +43,3 @@ func (c *Config) Dump(w io.Writer) {
 
 	fmt.Fprintf(w, "%s\n", string(bb))
 }
-
-// Save saves the config to disk.
-func (c *Config) Save(path string) error {
-	c.mx.RLock()
-	defer c.mx.RUnlock()
-
-	if err := EnsureDirPath(path, DefaultDirMod); err != nil {
-		return err
-	}
-	cfg, err := yaml.Marshal(c)
-	if err != nil {
-		return err
-	}
-
-	return os.WriteFile(path, cfg, DefaultFileMod)
-}
