@@ -56,7 +56,7 @@ func (n *Node) ToggleCordon(path string, cordon bool) error {
 		}
 		return fmt.Errorf("node is already uncordoned")
 	}
-	dial, err := n.GetFactory().Client().Dial()
+	dial, err := n.getFactory().Client().Dial()
 	if err != nil {
 		return err
 	}
@@ -98,7 +98,7 @@ func (n *Node) Drain(path string, opts DrainOptions, w io.Writer) error {
 		}
 	}
 
-	dial, err := n.GetFactory().Client().Dial()
+	dial, err := n.getFactory().Client().Dial()
 	if err != nil {
 		return err
 	}
@@ -189,7 +189,7 @@ func (n *Node) List(ctx context.Context, ns string) ([]runtime.Object, error) {
 // CountPods counts the pods scheduled on a given node.
 func (n *Node) CountPods(nodeName string) (int, error) {
 	var count int
-	oo, err := n.GetFactory().List("v1/pods", client.BlankNamespace, false, labels.Everything())
+	oo, err := n.getFactory().List("v1/pods", client.BlankNamespace, false, labels.Everything())
 	if err != nil {
 		return 0, err
 	}
@@ -213,7 +213,7 @@ func (n *Node) CountPods(nodeName string) (int, error) {
 
 // GetPods returns all pods running on given node.
 func (n *Node) GetPods(nodeName string) ([]*v1.Pod, error) {
-	oo, err := n.GetFactory().List("v1/pods", client.BlankNamespace, false, labels.Everything())
+	oo, err := n.getFactory().List("v1/pods", client.BlankNamespace, false, labels.Everything())
 	if err != nil {
 		return nil, err
 	}
