@@ -67,6 +67,12 @@ var stdGroups = []string{
 	"v1",
 }
 
+func (m ResourceMetas) clear() {
+	for k := range m {
+		delete(m, k)
+	}
+}
+
 // Meta represents available resource metas.
 type Meta struct {
 	resMetas ResourceMetas
@@ -188,7 +194,7 @@ func (m *Meta) LoadResources(f Factory) error {
 	m.mx.Lock()
 	defer m.mx.Unlock()
 
-	m.resMetas = make(ResourceMetas, 100)
+	m.resMetas.clear()
 	if err := loadPreferred(f, m.resMetas); err != nil {
 		return err
 	}
@@ -313,8 +319,8 @@ func loadK9s(m ResourceMetas) {
 
 func loadHelm(m ResourceMetas) {
 	m[client.NewGVR("helm")] = metav1.APIResource{
-		Name:       "chart",
-		Kind:       "Chart",
+		Name:       "helm",
+		Kind:       "Helm",
 		Namespaced: true,
 		Verbs:      []string{"delete"},
 		Categories: []string{helmCat},
