@@ -174,7 +174,7 @@ func (s *StatefulSet) Pod(fqn string) (string, error) {
 }
 
 func (s *StatefulSet) getStatefulSet(fqn string) (*appsv1.StatefulSet, error) {
-	o, err := s.GetFactory().Get(s.gvr.String(), fqn, true, labels.Everything())
+	o, err := s.getFactory().Get(s.gvrStr(), fqn, true, labels.Everything())
 	if err != nil {
 		return nil, err
 	}
@@ -191,7 +191,7 @@ func (s *StatefulSet) getStatefulSet(fqn string) (*appsv1.StatefulSet, error) {
 // ScanSA scans for serviceaccount refs.
 func (s *StatefulSet) ScanSA(ctx context.Context, fqn string, wait bool) (Refs, error) {
 	ns, n := client.Namespaced(fqn)
-	oo, err := s.GetFactory().List(s.GVR(), ns, wait, labels.Everything())
+	oo, err := s.getFactory().List(s.GVR(), ns, wait, labels.Everything())
 	if err != nil {
 		return nil, err
 	}
@@ -217,7 +217,7 @@ func (s *StatefulSet) ScanSA(ctx context.Context, fqn string, wait bool) (Refs,
 // Scan scans for cluster resource refs.
 func (s *StatefulSet) Scan(ctx context.Context, gvr client.GVR, fqn string, wait bool) (Refs, error) {
 	ns, n := client.Namespaced(fqn)
-	oo, err := s.GetFactory().List(s.GVR(), ns, wait, labels.Everything())
+	oo, err := s.getFactory().List(s.GVR(), ns, wait, labels.Everything())
 	if err != nil {
 		return nil, err
 	}
