@@ -74,8 +74,8 @@ func (y *YAML) filter(q string, lines []string) fuzzy.Matches {
 	if q == "" {
 		return nil
 	}
-	if dao.IsFuzzySelector(q) {
-		return y.fuzzyFilter(strings.TrimSpace(q[2:]), lines)
+	if f, ok := dao.HasFuzzySelector(q); ok {
+		return y.fuzzyFilter(strings.TrimSpace(f), lines)
 	}
 	return rxFilter(q, lines)
 }
