@@ -35,6 +35,7 @@ func (Node) Header(_ string) Header {
 		HeaderColumn{Name: "NAME"},
 		HeaderColumn{Name: "STATUS"},
 		HeaderColumn{Name: "ROLE"},
+		HeaderColumn{Name: "ARCH", Wide: true},
 		HeaderColumn{Name: "TAINTS"},
 		HeaderColumn{Name: "VERSION"},
 		HeaderColumn{Name: "KERNEL", Wide: true},
@@ -90,6 +91,7 @@ func (n Node) Render(o interface{}, ns string, r *Row) error {
 		no.Name,
 		join(statuses, ","),
 		join(roles, ","),
+		no.Status.NodeInfo.Architecture,
 		strconv.Itoa(len(no.Spec.Taints)),
 		no.Status.NodeInfo.KubeletVersion,
 		no.Status.NodeInfo.KernelVersion,
