@@ -37,11 +37,23 @@ func NewCommand(app *App) *Command {
 	}
 }
 
+// AliasesFor gather all known aliases for a given resource.
+func (c *Command) AliasesFor(s string) []string {
+	aa := make([]string, 0, 10)
+	for k, v := range c.alias.Alias {
+		if v == s {
+			aa = append(aa, k)
+		}
+	}
+
+	return aa
+}
+
 // Init initializes the command.
 func (c *Command) Init(path string) error {
 	c.alias = dao.NewAlias(c.app.factory)
 	if _, err := c.alias.Ensure(path); err != nil {
-		log.Error().Err(err).Msgf("command init failed!")
+		log.Error().Err(err).Msgf("Alias ensure failed!")
 		return err
 	}
 	customViewers = loadCustomViewers()
@@ -128,9 +140,6 @@ func (c *Command) xrayCmd(p *cmd.Interpreter) error {
 	if err := c.app.switchNS(ns); err != nil {
 		return err
 	}
-	if err := c.app.Config.Save(); err != nil {
-		return err
-	}
 
 	return c.exec(p, client.NewGVR("xrays"), NewXray(gvr), true)
 }
@@ -309,9 +318,6 @@ func (c *Command) exec(p *cmd.Interpreter, gvr client.GVR, comp model.Component,
 	if clearStack {
 		cmd := contextRX.ReplaceAllString(p.GetLine(), "")
 		c.app.Config.SetActiveView(cmd)
-		if err := c.app.Config.Save(); err != nil {
-			log.Error().Err(err).Msg("Config save failed!")
-		}
 	}
 	if err := c.app.inject(comp, clearStack); err != nil {
 		return err
