@@ -11,6 +11,8 @@ import (
 
 	"github.com/derailed/k9s/internal/client"
 	"github.com/rs/zerolog/log"
+	v1 "k8s.io/api/core/v1"
+	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 	"k8s.io/apimachinery/pkg/labels"
 	"k8s.io/apimachinery/pkg/runtime"
 	di "k8s.io/client-go/dynamic/dynamicinformer"
@@ -75,7 +77,7 @@ func (f *Factory) List(gvr, ns string, wait bool, labels labels.Selector) ([]run
 		return nil, err
 	}
 	if client.IsAllNamespace(ns) {
-		ns = client.AllNamespaces
+		ns = client.BlankNamespace
 	}
 
 	var oo []runtime.Object
@@ -131,7 +133,7 @@ func (f *Factory) Get(gvr, fqn string, wait bool, sel labels.Selector) (runtime.
 
 func (f *Factory) waitForCacheSync(ns string) {
 	if client.IsClusterWide(ns) {
-		ns = client.AllNamespaces
+		ns = client.BlankNamespace
 	}
 
 	f.mx.RLock()
@@ -182,7 +184,7 @@ func (f *Factory) SetActiveNS(ns string) error {
 func (f *Factory) isClusterWide() bool {
 	f.mx.RLock()
 	defer f.mx.RUnlock()
-	_, ok := f.factories[client.AllNamespaces]
+	_, ok := f.factories[client.BlankNamespace]
 
 	return ok
 }
@@ -221,7 +223,7 @@ func (f *Factory) ForResource(ns, gvr string) (informers.GenericInformer, error)
 
 func (f *Factory) ensureFactory(ns string) (di.DynamicSharedInformerFactory, error) {
 	if client.IsClusterWide(ns) {
-		ns = client.AllNamespaces
+		ns = client.BlankNamespace
 	}
 	f.mx.Lock()
 	defer f.mx.Unlock()
@@ -275,8 +277,8 @@ func (f *Factory) ForwarderFor(path string) (Forwarder, bool) {
 	return fwd, ok
 }
 
-// BOZO!! Review!!!
 // ValidatePortForwards check if pods are still around for portforwards.
+// BOZO!! Review!!!
 func (f *Factory) ValidatePortForwards() {
 	for k, fwd := range f.forwarders {
 		tokens := strings.Split(k, ":")
@@ -288,10 +290,19 @@ func (f *Factory) ValidatePortForwards() {
 		if len(paths) < 1 {
 			log.Error().Msgf("Invalid path %q", tokens[0])
 		}
-		_, err := f.Get("v1/pods", paths[0], false, labels.Everything())
+		o, err := f.Get("v1/pods", paths[0], false, labels.Everything())
 		if err != nil {
 			fwd.Stop()
 			delete(f.forwarders, k)
+			continue
+		}
+		var pod v1.Pod
+		if err := runtime.DefaultUnstructuredConverter.FromUnstructured(o.(*unstructured.Unstructured).Object, &pod); err != nil {
+			continue
+		}
+		if pod.GetCreationTimestamp().Time.Unix() > fwd.Age().Unix() {
+			fwd.Stop()
+			delete(f.forwarders, k)
 		}
 	}
 }
